cumulusci.tasks.bulkdata package
================================

Subpackages
-----------

.. toctree::

   cumulusci.tasks.bulkdata.tests

Submodules
----------


.. automodule:: cumulusci.tasks.bulkdata.base_generate_data_task
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.bulkdata.delete
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.bulkdata.extract
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.bulkdata.factory_utils
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.bulkdata.generate
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.bulkdata.generate_and_load_data
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.bulkdata.generate_and_load_data_from_yaml
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.bulkdata.generate_from_yaml
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.bulkdata.generate_mapping
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.bulkdata.load
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.bulkdata.utils
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: cumulusci.tasks.bulkdata
   :members:
   :undoc-members:
   :show-inheritance:
